@@ -13,11 +13,14 @@ pub fn build_request(parameters: BTreeMap<String, String>) -> String {
     request
 }
 
-pub fn build_signed_request(parameters: BTreeMap<String, String>, recv_window: u64,) -> Result<String> {
+pub fn build_signed_request(
+    parameters: BTreeMap<String, String>, recv_window: u64,
+) -> Result<String> {
     build_signed_request_custom(parameters, recv_window, SystemTime::now())
 }
 
-pub fn build_signed_request_custom(mut parameters: BTreeMap<String, String>, recv_window: u64, start: SystemTime,
+pub fn build_signed_request_custom(
+    mut parameters: BTreeMap<String, String>, recv_window: u64, start: SystemTime,
 ) -> Result<String> {
     if recv_window > 0 {
         parameters.insert("recvWindow".into(), recv_window.to_string());
